Description: NASA will receive $18 billion for 2015, more than a half a billion dollars above the Obama administration’s original request, under the terms of an omnibus spending bill released late Dec. 9.

Follow
TRENDING: Skywatching Guide // Space Webcasts // Mars Rover Curiosity // Solar Flares // Space Photos // Space Videos // Telescopes for Beginners

# NASA Receives $18 Billion in Omnibus Spending Bill

by Jeff Foust, SpaceNews Writer | December 12, 2014 03:20pm ET

The logo of NASA, the National Aeronautics and Space Administration. Credit: NASA View full size image

WASHINGTON — NASA will receive $18 billion for 2015, more than a half a billion dollars above the Obama administration’s original request, under the terms of an omnibus spending bill released late Dec. 9.

The appropriations bill, which funds NASA and most of the rest of the federal government for the remainder of the fiscal year that began Oct. 1, gives the agency $17.99 billion, including increases for several major exploration and science programs. That total is $530 million above the administration's request of $17.46 billion for the agency, and about $100 million above separate House and Senate appropriations bills considered earlier this year. It's also nearly $350 million above NASA’s enacted 2014 budget of $17.65 billion.

Two major elements of NASA's exploration strategy won funding boosts in the final bill. The Space Launch System heavy-lift rocket will receive $1.7 billion, an increase of $320 million over the administration’s request. The Orion spacecraft will get $1.194 billion, an increase of $141.2 million over the request.

Artist’s concept of Orion separating from SLS rocket.
Credit: NASA
View full size image

The bill also requires NASA to submit in its next budget proposal five-year funding projections for the SLS and Orion programs that match the budget and schedule estimates for those programs developed in recent or ongoing reviews. Those estimates, developed by NASA for a program milestone called Key Decision Point C (KDP-C), were completed for SLS in August and will be completed for Orion in the spring of 2015.

The bill specifically requires those projections for the SLS to show completion by December 2017. The KDP-C review for SLS estimated that the vehicle would be ready for its first launch no later than November 2018.

NASA's planetary science program won an increase of $157 million, to $1.438 billion for 2015. The bill sets aside $100 million of that funding for a proposed Europa mission, for which the White House had requested just $15 million.

NASA's astrophysics program won a $77.5 million increase, to $684.8 million, in the omnibus bill. That includes $70 million for the Stratospheric Observatory for Infrared Astronomy, an airborne telescope for which NASA requested only $12 million. NASA had planned to mothball the flying observatory in 2015 if it could not find partners to fund the telescope's annual operating cost of about $85 million.

The SOFIA flying observatory.
Credit: NASA
View full size image

NASA's commercial crew program received $805 million in the bill, less than the requested $848 million but more than the program received in previous years. The omnibus bill leaves out a controversial provision from the Senate's appropriations bill that would have required certified cost and pricing data from commercial crew companies. That language was opposed by many supporters of the commercial crew program, as well as by the White House.

NASA's aeronautics program received $651 million, an increase of $100 million over the administration’s request. In a report accompanying the bill, appropriators directed NASA to apply the additional funds proportionally across the programs in that mission directorate.

NASA's space technology program was cut by nearly $110 million from the administration's request, to $596 million. Appropriators offered no specific rationale for the cut in report language, nor direction on how to apply the reduced funding among its programs.

Other parts of the agency's budget saw only minimal changes from the administration's request. The bill includes $3.828 billion for space operations; $2.759 billion for safety, security, and mission operations (formerly known as cross-agency support); $419.1 million for construction; $119 million for education; and $37 million for the agency’s inspector general.

The overall bill, sometimes called a "cromnibus" since it serves as only a continuing resolution (CR) for the Department of Homeland Security through February 2015, was slated to be voted on by the House Dec. 11, and immediately thereafter by the Senate. The federal government is currently funded by a continuing resolution that expired at midnight of Dec. 11, and another short-term continuing resolution, lasting only a few days, was needed to keep the government operating until Congress passes the omnibus bill.

This story was provided by SpaceNews, dedicated to covering all aspects of the space industry.

### EDITOR'S RECOMMENDATIONS

- More Space Industry News from SpaceNews
- Gallery: President Obama and NASA
- 50 Years of Presidential Visions for Space Exploration

More from Space.com